diff mbox series

usb: typec: tcpm: Fix spelling mistake "atleast" -> "at least"

Message ID 20210826123959.14838-1-colin.king@canonical.com
State New
Headers show
Series usb: typec: tcpm: Fix spelling mistake "atleast" -> "at least" | expand

Commit Message

Colin King Aug. 26, 2021, 12:39 p.m. UTC
From: Colin Ian King <colin.king@canonical.com>

There are spelling mistakes in a comment and a literal string.
Fix them.

Signed-off-by: Colin Ian King <colin.king@canonical.com>
---
 drivers/usb/typec/tcpm/tcpm.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
diff mbox series

Patch

diff --git a/drivers/usb/typec/tcpm/tcpm.c b/drivers/usb/typec/tcpm/tcpm.c
index 049f4c61ee82..b981fc39fa3c 100644
--- a/drivers/usb/typec/tcpm/tcpm.c
+++ b/drivers/usb/typec/tcpm/tcpm.c
@@ -278,7 +278,7 @@  struct pd_mode_data {
  * @req_max_curr: Requested max current of the port partner
  * @req_out_volt: Requested output voltage to the port partner
  * @req_op_curr: Requested operating current to the port partner
  * @supported: Parter has atleast one APDO hence supports PPS
  * @active: PPS mode is active
  */
 struct pd_pps_data {
@@ -2050,7 +2050,7 @@  enum pdo_err {
 
 static const char * const pdo_err_msg[] = {
 	[PDO_ERR_NO_VSAFE5V] =
-	" err: source/sink caps should atleast have vSafe5V",
+	" err: source/sink caps should at least have vSafe5V",
 	[PDO_ERR_VSAFE5V_NOT_FIRST] =
 	" err: vSafe5V Fixed Supply Object Shall always be the first object",
 	[PDO_ERR_PDO_TYPE_NOT_IN_ORDER] =
@@ -278,7 +278,7 @@  struct pd_mode_data {
  * @req_out_volt: Requested output voltage to the port partner
  * @req_op_curr: Requested operating current to the port partner
- * @supported: Parter has atleast one APDO hence supports PPS
+ * @supported: Parter has at least one APDO hence supports PPS
  * @active: PPS mode is active
  */